--[[****************************************************************************
ActionBars.lua

This file contains the data for the actionbars supported by Mecaire's Macrotexter.

******************************************************************************]]

--[[****************************************************************************
MIT_GetActionbars()

This function returns a table of data for supported actionbars.

******************************************************************************]]
function MMT_GetActionbars()

	local t = {};       -- The table to be returned.
	
	-- Blizzard default UI main actionbar (multi-page)
	t[1] = {};
	t[1].id = "BLIZZ_MAIN";
	t[1].type = "multi_page";
	t[1].min_slot = 1;
	t[1].max_slot = 72;
	t[1].button_name = "ActionButton";
	t[1].num_buttons = 12;
	t[1].active = true;

	-- Blizzard default UI bottom left actionbar
	t[2] = {};
	t[2].id = "BLIZZ_BOTTOM_LEFT";
	t[2].type = nil;
	t[2].min_slot = 61;
	t[2].max_slot = 72;
	t[2].button_name = "MultiBarBottomLeftButton";
	t[2].num_buttons = 12;
	t[2].active = true;
	
	-- Blizzard default UI bottom right actionbar
	t[3] = {};
	t[3].id = "BLIZZ_BOTTOM_RIGHT";
	t[3].type = nil;
	t[3].min_slot = 49;
	t[3].max_slot = 60;
	t[3].button_name = "MultiBarBottomRightButton";
	t[3].num_buttons = 12;
	t[3].active = true;
	
	-- Blizzard default UI right actionbar
	t[4] = {};
	t[4].id = "BLIZZ_RIGHT";
	t[4].type = nil;
	t[4].min_slot = 25;
	t[4].max_slot = 36;
	t[4].button_name = "MultiBarRightButton";
	t[4].num_buttons = 12;
	t[4].active = true;	

	-- Blizzard default UI second right actionbar
	t[5] = {};
	t[5].id = "BLIZZ_LEFT";
	t[5].type = nil;
	t[5].min_slot = 37;
	t[5].max_slot = 48;
	t[5].button_name = "MultiBarLeftButton";
	t[5].num_buttons = 12;
	t[5].active = true;	

	-- Blizzard default UI bonus actionbar (stances)
	t[6] = {};
	t[6].id = "BLIZZ_BONUS";
	t[6].type = "stance_driven";
	t[6].min_slot = 73;
	t[6].max_slot = 108;
	t[6].button_name = "BonusActionButton";
	t[6].num_buttons = 12;
	t[6].active = true;

	-- Bartender3 bar 1
	t[7] = {};
	t[7].id = "BT3_BAR1";
	t[7].type = "bartender";
	t[7].min_slot = 1;
	t[7].max_slot = 72;
	t[7].button_name = "BT3Button";
	t[7].num_buttons = 12;
	t[7].index = 1;

	-- Bartender3 bar 2-10
	for iCount = 2, 10 do
		t[iCount + 6] = {};
		t[iCount + 6].id = "BT3_BAR"..iCount;
		t[iCount + 6].type = "bartender";
		t[iCount + 6].button_name = "BT3Button";
		t[iCount + 6].index = iCount;
	end

	-- Next table index: 17

	return t;
end

--[[****************************************************************************
MMT_StanceForSlot(intSlot, oBar, strClass)

This function returns the numeric stance value for the given slot number and
character class.

Returns 0 if bStanceDriven is false or intSlotNumber is not used for a 
stance for that class.

strClass should be the English class in all CAPS.

Good references: http://www.wowwiki.com/ActionSlot
	and http://www.wowwiki.com/API_GetShapeshiftForm

******************************************************************************]]
function MMT_StanceForSlot(intSlot, oBar, strClass)

	if oBar.type ~= "stance_driven" then
		return 0;
	elseif strClass == "WARRIOR" then
		if intSlot >= 73 and intSlot <= 84 then		 	-- Battle Stance
			return 1;		
		elseif intSlot >= 85 and intSlot <= 96 then	 	-- Defensive Stance
			return 2;
		elseif intSlot >= 97 and intSlot <= 108 then	-- Berserker Stance
		    return 3;
		else
			return 0;
		end
	elseif strClass == "DRUID" then
		if intSlot >= 73 and intSlot <= 84 then			-- Cat form
			return 3;
		elseif intSlot >= 97 and intSlot <= 108 then	-- Bear/Dire Bear
			return 1;
		else
			return 0;
		end							
	elseif strClass == "ROGUE" then
		if intSlot >= 73 and intSlot <= 84 then			-- Stealth
			return 1;
		else
			return 0;
		end
	else
		return 0;		
	end
end

--[[****************************************************************************
MMT_PageForSlot(intSlot)

This function returns the action page number for the given slot number.

******************************************************************************]]
function MMT_PageForSlot(intSlot, oBar)
	if oBar.type ~= "multi_page" then
	    return 0;
	else
	    return math.floor((intSlot - 1) / oBar.num_buttons) + 1;
	end
end