--[[****************************************************************************
SpellCategory.lua

In this file we define the categories and macro templates for spells.

--------------------------------------------------------------------------------
Editing this file
--------------------------------------------------------------------------------

If you're editing this file in Notepad, you will probably want to *disable*
Word Wrap.

The lines in this file have the form:
t[category] = "macro";

If you add a category, you may find it useful to include a note (like in the
included examples) to indicate what the category is for.  You can do this by
putting two dashes -- in front of your note.

Each category must be a unique value.  If you copy-and-paste a line in this
file, you must change the category to an unused value!

"macro" is the macro you want to use for spells of that category.

Don't forget you must assign spells individually to their categories in
SpellList.lua to use the macros here.  Each spell can only have one
category.

If you find that some spells seem to fall into two categories, you probably
need to create a new, separate category for those, and write a different macro
for those spells.

(See SpellList.lua to assign a category to each spell.)

--------------------------------------------------------------------------------
How to write the macro
--------------------------------------------------------------------------------
Spell name and rank:
	To show Macrotexter where the spell name and rank (for a spell in this
	category) should be "filled in", include SPELLNR in your macro.
	(Stands for Spell Name and Rank).

	If you want to use a particular rank of the spell, include SPELLN#, where #
	is the rank number.  For example, use SPELLN1 ("one") to use Rank 1, or
	SPELLN3 to use Rank 3.

Selfcasting:
	If you want a spell to use the selfcasting provided by Mecaire's
	Macrotexter, just include SELFCAST after the /cast statement, then
	write the rest of the macro normally.

Quote marks:
	If your macro contains double quote marks, you should be able to replace
	them with single quote marks like this one: '

A note about (the lack of a) character limit:
	In a normal macro in WoW, you may have noticed that you can only write
	256 characters.  The macros you write here are not normal macros--they are
	"macrotext", and they can contain many more characters.  How many more?  I
	don't know!  I've used 380-some character macrotexts, and they worked great.

If you need help:
	There are a few sticky posts on the UI forum showing how to write a macro.
	If you're having trouble or those don't help, you can always ask on that
	forum.  Remember that if someone gives you a macro for a particular spell,
	you will need to replace the spell name with SPELLNR when you enter the
	special macro below.  Also, remember you have to surround the macro with
	quotes when you write it below.
	
******************************************************************************]]

function MMT_GetSpellCategories()

local t = {};       -- The table of spell categories to be returned.

-----Make all edits BELOW this line!--------------------------------------------


-- Category 1: Selfcast-enabled beneficial spells that implied-target.
-- (This category is set up by default in SpellList.lua.)
t[1] = "/cast SELFCAST [help] SPELLNR;[target=targettarget,help] SPELLNR; SPELLNR;";


-- Category 2: Selfcast-enabled spells.  (No implied targeting.)
-- (This category is set up by default in SpellList.lua.)
t[2] = "/cast SELFCAST SPELLNR";


-- Category 3: Harmful spells that implied-target.
-- (This category is set up by default in SpellList.lua.)
t[3] = "/cast [harm] SPELLNR; [target=targettarget,harm] SPELLNR; SPELLNR";


-- Category 4: Alternately, you can use this macro for channeled spells
-- (such as Mind Flay, Starshards, Arcane Missiles, Hurricane, Tranquility).
--  If you press the spell button twice accidentally, it won't break your 
-- channeling. (Idea contributed by Isildifin of Ursin & written by Ignayshus
-- of Bleeding Hollow.)
-- (If you want to use this, remember to set this category for the proper spells
-- in SpellList.lua.)
t[4] = "/cast [harm,nochanneling] SPELLNR; [target=targettarget,harm,nochanneling] SPELLNR; [nochanneling] SPELLNR";


-- Category 5: Priests can use this to automatically drop out of Shadowform-----
-- when trying to cast a beneficial holy spell.  (Contributed by Ignayshus
-- of Bleeding Hollow.)
-- Note: Be careful if you have Spirit of Redemption.  I haven't tested this in TBC.
-- Pre-TBC, SoR had the same stance value as Shadowform.  If that is still the
-- case, this macro will prevent you from healing in Spirit of Redemption form.
-- (If you want to use this, remember to set this category for the proper holy spells
-- in SpellList.lua.)
t[5] = "/cast [stance:1]Shadowform; SELFCAST [help] SPELLNR;[target=targettarget,help] SPELLNR; SPELLNR;";


-- Category 6: A melee skills macro, from Cotan of Tichondrius.  Makes the
-- action button target your focus (if it exists and isn't dead and is an enemy)
-- if shift is down, and target mouseover (same conditions) if ctrl is down.
-- Note: Be careful if your shift or ctrl keys are mapped to do other things.
-- (If you want to use this, remember to set this category for the proper spells
-- in SpellList.lua.)
t[6] = "/cast [modifier:shift,target=focus,exists,nodead,harm] SPELLNR; [modifier:ctrl,target=mouseover,exists,nodead,harm] SPELLNR; SPELLNR;";


-- Category 7: Non-targeted crowd control Spells - hold Ctrl to use Rank 1
-- instead of top rank.
t[7] = "/cast [modifier:ctrl] SPELLN1; SPELLNR";

-- Category 8: Targeted crowd control spells with implied targeting - hold Ctrl
-- to use Rank 1 instead of top rank.
t[8] = "/cast [modifier:ctrl,harm] SPELLN1; [modifier:ctrl,target=targettarget,harm] SPELLN1; [modifier:ctrl] SPELLN1; [harm] SPELLNR; [target=targettarget,harm] SPELLNR; SPELLNR"

-- Category 9: Your description here.
--t[9] = "your-macro-here";


-----Make all edits ABOVE this line!--------------------------------------------
return t;

end