--[[****************************************************************************
SpellList.lua

This file contains the list of spells affected by Mecaire's Macrotexter.

Edit this file if you need to add a spell or change a spell's behavior.
Default values for the spell category are:
  1 indicates a beneficial spell that uses implied targeting.
  2 indicates a spell that uses selfcasting, but *DOES NOT* use
    implied targeting.
  3 indicates a harmful spell that uses implied targeting.
  
(If you changed SpellCategory.lua, your categories will be different.  While
editing this file you may find it helpful to view your edited SpellCategory.lua
alongside it for reference.)
  
Pay close attention and make sure you edit spells for the correct class.
 
You can remove a spell from the list by typing two dashes -- at the beginning
of the line.

If a spell has two dashes in front of it, that means it is remarked out and
Macrotexter will ignore it.  If you are defining a category for that spell,
be sure to remove the two dashes.

Racial spells and bandages are near the end of the file.

******************************************************************************]]

function MMT_GetSpellList(strClass)

local t = {};       -- Initialize the table to be returned.

--[[****************************************************************************
DRUID Spells
******************************************************************************]]
if strClass == "DRUID" then
    -- Cures
	t["Abolish Poison"] = 1;
	t["Cure Poison"] = 1;
	t["Remove Curse"] = 1;
	
    -- Heals
	t["Healing Touch"] = 1;
	t["Lifebloom"] = 1;
	t["Regrowth"] = 1;
	t["Rejuvenation"] = 1;
	t["Swiftmend"] = 1;
	--t["Tranquility"] =
	
    -- Buffs
	--t["Barkskin"] = 
	t["Gift of the Wild"] = 1;
	t["Innervate"] = 2;                -- No Implied Targeting - Selfcast Only
	t["Mark of the Wild"] = 1;
	--t["Nature's Grasp"] =
	--t["Rebirth"] =
	t["Thorns"] = 1;
	
	-- Teleports
	--t["Teleport: Moonglade"] =
	
    -- Harmful spells:
	t["Cyclone"] = 3;
	t["Entangling Roots"] = 3;
	t["Faerie Fire"] = 3;
	t["Faerie Fire (Feral)"] = 3;
	t["Force of Nature"] = 3;
	t["Hibernate"] = 3;
	--t["Hurricane"] =
	t["Insect Swarm"] = 3;
	t["Moonfire"] = 3;
	t["Soothe Animal"] = 3;
	t["Starfire"] = 3;
	t["Wrath"] = 3;
	
	-- Shapeshifting: Un-remark and set a category if needed.
	--t["Aquatic Form"] = 
	--t["Bear Form"] = 
	--t["Cat Form"] = 
	--t["Dire Bear Form"] = 
	--t["Flight Form"] = 
	--t["Travel Form"] =
	
	-- Targeted taunt
	t["Growl"] = 3;
	
	-- Feral skills: Un-remark and set a category if needed.
	--t["Bash"] =
	--t["Challenging Roar"] =
	--t["Claw"] =
	--t["Cower"] = 
	--t["Dash"] =
	--t["Demoralizing Roar"] =
	--t["Enrage"] =
	--t["Ferocious Bite"] =
	--t["Frenzied Regeneration"] =
	--t["Lacerate"] = 
	--t["Maim"] = 
	--t["Mangle (Bear)"] =
	--t["Mangle (Cat)"] =
	--t["Maul"] =
	--t["Pounce"] =
	--t["Prowl"] =
	--t["Rake"] =
	--t["Ravage"] =
	--t["Rip"] = 
	--t["Shred"] =
	--t["Swipe"] = 
	--t["Tiger's Fury"] =
	--t["Track Humanoids"] = 
	
--[[****************************************************************************
HUNTER Spells
******************************************************************************]]
elseif strClass == "HUNTER" then

	-- Harmful spells
	t["Hunter's Mark"] = 3;

	-- Marksmanship skills: Un-remark and set a category if needed.
	--t["Aimed Shot"] = 
	--t["Arcane Shot"] = 
	--t["Auto Shot"] =
	--t["Concussive Shot"] = 
	--t["Distracting Shot"] =
	--t["Flare"] = 
	--t["Multi-Shot"] = 
	--t["Rapid Fire"] = 
	--t["Scorpid Sting"] = 
	--t["Serpent Sting"] =
	--t["Steady Shot"] =
	--t["Tranquilizing Shot"] = 
	--t["Trueshot Aura"] =
	--t["Viper Sting"] =
	--t["Volley"] =
		
	-- Aspects: Un-remark and set a category if needed.
	--t["Aspect of the Beast"] =
	--t["Aspect of the Cheetah"] =
	--t["Aspect of the Hawk"] =
	--t["Aspect of the Monkey"] =
	--t["Aspect of the Pack"] =
	--t["Aspect of the Viper"] =
	--t["Aspect of the Wild"] = 
	
	-- Beast Mastery skills: Un-remark and set a category if needed.
	--t["Beast Lore"] = 
	--t["Call Pet"] = 
	--t["Dismiss Pet"] =
	--t["Eagle Eye"] =
	--t["Eyes of the Beast"] = 
	--t["Feed Pet"] = 
	--t["Kill Command"] =
	--t["Mend Pet"] =
	--t["Revive Pet"] =
	--t["Scare Beast"] = 
	--t["Tame Beast"] =
	
	-- Survival skills: Un-remark and set a category if needed.
	--t["Counterattack"] = 
	--t["Disengage"] = 
	--t["Feign Death"] =
	--t["Misdirection"] = 
	--t["Mongoose Bite"] = 
	--t["Raptor Strike"] =
	--t["Wing Clip"] =
	--t["Wyvern Sting"] =
	
	-- Traps: Un-remark and set a category if needed.
	--t["Explosive Trap"] =
	--t["Freezing Trap"] =
	--t["Frost Trap"] =
	--t["Immolation Trap"] =
	--t["Snake Trap"] =
	
	-- Tracking: Un-remark and set a category if needed.
	--t["Track Beasts"] =
	--t["Track Demons"] =
	--t["Track Dragonkin"] =
	--t["Track Elementals"] =
	--t["Track Giants"] =
	--t["Track Hidden"] =
	--t["Track Humanoids"] =
	--t["Track Undead"] =
	
	
--[[****************************************************************************
MAGE Spells
******************************************************************************]]
elseif strClass == "MAGE" then

	-- Cures
	t["Remove Lesser Curse"] = 1;
	
	-- Buffs
	t["Amplify Magic"] = 1;
	t["Arcane Brilliance"] = 1;
	t["Arcane Intellect"] = 1;
	t["Dampen Magic"] = 1;
	--t["Evocation"] = 
	--t["Fire Ward"] =
	--t["Frost Armor"] =
	--t["Frost Ward"] =
	--t["Ice Armor"] =
	--t["Ice Barrier"] =
	--t["Invisibility"] =
	--t["Mage Armor"] =
	--t["Mana Shield"] =
	--t["Molten Armor"] =
	--t["Slow Fall"] =
	
	-- Targeted Harmful spells
	t["Arcane Blast"] = 3;
	t["Arcane Missiles"] = 3;		-- Change to "4" to prevent breaking channeling
	t["Counterspell"] = 3;
	t["Detect Magic"] = 3;
	t["Fire Blast"] = 3;
	t["Fireball"] = 3;
	t["Frostbolt"] = 3;
	t["Ice Lance"] = 3;
	t["Polymorph"] = 3;
	t["Polymorph: Cow"] = 3;
	t["Polymorph: Pig"] = 3;
	t["Polymorph: Turtle"] = 3;
	t["Pyroblast"] = 3;
	t["Scorch"] = 3;
	t["Spellsteal"] = 3;
	
	-- Ground/Non-targeted Harmful spells
	--t["Arcane Explosion"] =
	--t["Blast Wave"] =
	--t["Blizzard"] = 
	--t["Cone of Cold"] =
	--t["Dragon's Breath"] =
	--t["Flamestrike"] =
	--t["Frost Nova"] =
	
	-- Teleports
	--t["Blink"] =
	--t["Portal: Darnassus"] =
	--t["Portal: Exodar"] =
	--t["Portal: Ironforge"] = 
	--t["Portal: Orgrimmar"] =
	--t["Portal: Shattrath"] =
	--t["Portal: Silvermoon"] =
	--t["Portal: Stormwind"] =
	--t["Portal: Thunder Bluff"] =
	--t["Portal: Undercity"] =
	--t["Teleport: Darnassus"] =
	--t["Teleport: Exodar"] =
	--t["Teleport: Ironforge"] =
	--t["Teleport: Orgrimmar"] =
	--t["Teleport: Shattrath"] =
	--t["Teleport: Silvermoon"] =
	--t["Teleport: Stormwind"] =
	--t["Teleport: Thunder Bluff"] =
	--t["Teleport: Undercity"] =
	
	-- Conjures
	--t["Conjure Food"] =
	--t["Conjure Mana Agate"] =
	--t["Conjure Mana Citrine"] =
	--t["Conjure Mana Emerald"] =
	--t["Conjure Mana Jade"] =
	--t["Conjure Mana Ruby"] =
	--t["Conjure Water"] =	
	
--[[****************************************************************************
PALADIN Spells
******************************************************************************]]
elseif strClass == "PALADIN" then

	-- Blessings
	t["Blessing of Freedom"] = 1;
	t["Blessing of Kings"] = 1;
	t["Blessing of Light"] = 1;
	t["Blessing of Might"] = 1;
	t["Blessing of Protection"] = 1;
	t["Blessing of Sacrifice"] = 1;
	t["Blessing of Salvation"] = 1;
	t["Blessing of Sanctuary"] = 1;
	t["Blessing of Wisdom"] = 1;
	t["Greater Blessing of Kings"] = 1;
	t["Greater Blessing of Light"] = 1;
	t["Greater Blessing of Might"] = 1;
	t["Greater Blessing of Salvation"] = 1;
	t["Greater Blessing of Sanctuary"] = 1;
	t["Greater Blessing of Wisdom"] = 1;
	
	-- Cures
	t["Cleanse"] = 1;
	--t["Mass Resurrection"] =
	t["Purify"] = 1;
	--t["Redemption"] =
	
	-- Heals
	t["Flash of Light"] = 1;
	t["Holy Light"] = 1;
	t["Lay on Hands"] = 1;
	
	-- Beneficial spells
	t["Divine Intervention"] = 1;
	t["Righteous Defense"] = 1;
	
	-- Harmful spells
	t["Avenger's Shield"] = 3;
	--t["Consecration"] =
	t["Exorcism"] = 3;
	t["Hammer of Justice"] = 3;
	t["Hammer of Wrath"] = 3;
    t["Holy Shock"] = 2;                -- Selfcast only - No implied targeting
	--t["Holy Wrath"] =
	--t["Judgement"] = 3;
	t["Repentance"] = 3;
	t["Turn Undead"] = 3;

	-- Self buffs
	--t["Avenging Wrath"] =
	--t["Divine Protection"] =
	--t["Divine Shield"] =
	--t["Holy Shield"] =
	--t["Righteous Fury"] =
	--t["Sense Undead"] =
	--t["Summon Charger"] =
	--t["Summon Warhorse"] =
	
	-- Auras
	--t["Concentration Aura"] =
	--t["Crusader Aura"] =
	--t["Devotion Aura"] =
	--t["Fire Resistance Aura"] =
	--t["Frost Resistance Aura"] =
	--t["Retribution Aura"] =
	--t["Shadow Resistance Aura"] =
	
	-- Seals
	--t["Seal of Blood"] =
	--t["Seal of Command"] =
	--t["Seal of Justice"] =
	--t["Seal of Light"] =
	--t["Seal of Righteousness"] =
	--t["Seal of Vengeance"] =
	--t["Seal of Wisdom"] =
	--t["Seal of the Crusader"] =
	

--[[****************************************************************************
PRIEST Spells
******************************************************************************]]
elseif strClass == "PRIEST" then

	-- Cures
	t["Abolish Disease"] = 1;
	t["Cure Disease"] = 1;
	t["Dispel Magic"] = 2;             -- Selfcast only - No implied targeting
	--t["Mass Dispel"] =
	
	-- Buffs
	t["Divine Spirit"] = 1;
	t["Fear Ward"] = 1;
	t["Power Infusion"] = 2;           -- Selfcast only - No implied targeting
	t["Power Word: Fortitude"] = 1;
    t["Power Word: Shield"] = 1;
	t["Prayer of Fortitude"] = 1;
	t["Prayer of Shadow Protection"] = 1;
	t["Prayer of Spirit"] = 1;
	--t["Resurrection"] =
	t["Shadow Protection"] = 1;

	-- Heals
	-- Change these values to "5" to automatically drop Shadowform.
	t["Binding Heal"] = 1;
	t["Circle of Healing"] = 1;
	--t["Desperate Prayer"] =
	t["Flash Heal"] = 1;
	t["Greater Heal"] = 1;
	t["Heal"] = 1;
	t["Lesser Heal"] = 1;
	--t["Prayer of Healing"] =
	t["Prayer of Mending"] = 1;
	t["Renew"] = 1;
	
	-- No target/any target
	--t["Holy Nova"] =
	--t["Lightwell"] =
	--t["Mind Vision"] =
	
	-- Harmful spells
	t["Devouring Plague"] = 3;
	t["Hex of Weakness"] = 3;
	t["Holy Fire"] = 3;
	t["Mana Burn"] = 3;
	t["Mind Blast"] = 3;
	t["Mind Control"] = 3;
	t["Mind Flay"] = 3;					-- Change to "4" to prevent breaking channeling
	t["Mind Soothe"] = 3;
	--t["Psychic Scream"] =
	t["Shackle Undead"] = 3;
	t["Shadow Word: Death"] = 3;
	t["Shadow Word: Pain"] = 3;
	t["Shadowfiend"] = 3;
	t["Silence"] = 3;
	t["Smite"] = 3;
	t["Starshards"] = 3;				-- Change to "4" to prevent breaking channeling
	t["Vampiric Embrace"] = 3;
	t["Vampiric Touch"] = 3;

   	-- Self buffs
	--t["Consume Magic"] =	
	--t["Elune's Grace"] =
	--t["Fade"] =
	--t["Feedback"] =
	--t["Inner Fire"] =
	--t["Levitate"] =
	--t["Shadowguard"] =
	--t["Symbol of Hope"] =
	--t["Touch of Weakness"] =
	
--[[****************************************************************************
ROGUE Spells
******************************************************************************]]
elseif strClass == "ROGUE" then
	
	-- Assassination skills
	--t["Ambush"] =
	--t["Cheap Shot"] =
	--t["Deadly Throw"] =
	--t["Envenom"] =
	--t["Eviscerate"] =
	--t["Expose Armor"] =
	--t["Garrote"] =
	--t["Kidney Shot"] =
	--t["Mutilate"] =
	--t["Rupture"] =
	--t["Slice and Dice"] =
	
	-- Combat skills
	--t["Backstab"] =
	--t["Evasion"] =
	--t["Feint"] =
	--t["Gouge"] =
	--t["Kick"] =
	--t["Shiv"] =
	--t["Sinister Strike"] =
	--t["Sprint"] =
	
	-- Subtlety skills
	--t["Blind"] =
	--t["Cloak of Shadows"] =
	--t["Disarm Trap"] =
	--t["Distract"] =
	--t["Hemorrhage"] =
	--t["Pick Pocket"] =
	--t["Sap"] =
	--t["Stealth"] =
	--t["Vanish"] =
	
--[[****************************************************************************
SHAMAN Spells
******************************************************************************]]
elseif strClass == "SHAMAN" then

	-- Cures
	t["Cure Disease"] = 1;
	t["Cure Poison"] = 1;
	
	-- Buffs
	--t["Ancestral Spirit"] =
	--t["Bloodlust"] =
	t["Earth Shield"] = 1;
	--t["Far Sight"] =
	--t["Heroism"] =
	t["Water Breathing"] = 1;
	t["Water Walking"] = 1;
	
	-- Heals
	t["Chain Heal"] = 1;
	t["Healing Wave"] = 1;
	t["Lesser Healing Wave"] = 1;
	
	-- Harmful spells
	t["Chain Lightning"] = 3;
	t["Earth Shock"] = 3;
	t["Flame Shock"] = 3;
	t["Frost Shock"] = 3;
	t["Lightning Bolt"] = 3;
	t["Purge"] = 3;
	
	-- Teleports
	--t["Astral Recall"] =
	
	-- Totems
	--t["Disease Cleansing Totem"] =
	--t["Earth Elemental Totem"] =
	--t["Earthbind Totem"] =
	--t["Fire Elemental Totem"] =
	--t["Fire Nova Totem"] =
	--t["Fire Resistance Totem"] =
	--t["Flametongue Totem"] =
	--t["Frost Resistance Totem"] =
	--t["Grace of Air Totem"] =
	--t["Grounding Totem"] =
	--t["Healing Stream Totem"] =
	--t["Magma Totem"] =
	--t["Mana Spring Totem"] =
	--t["Nature Resistance Totem"] =
	--t["Poison Cleansing Totem"] =
	--t["Searing Totem"] =
	--t["Sentry Totem"] =
	--t["Stoneclaw Totem"] =
	--t["Stoneskin Totem"] =
	--t["Strength of Earth Totem"] =
	--t["Tranquil Air Totem"] =
	--t["Tremor Totem"] =
	--t["Windfury Totem"] =
	--t["Windwall Totem"] =
	--t["Wrath of Air Totem"] =
	
	-- Self buffs
	--t["Flametongue Weapon"] =
	--t["Frostbrand Weapon"] =
	--t["Ghost Wolf"] =
	--t["Lightning Shield"] =
	--t["Reincarnation"] =
	--t["Rockbiter Weapon"] =
	--t["Totemic Call"] =
	--t["Water Shield"] =
	--t["Windfury Weapon"] =
	
--[[****************************************************************************
WARLOCK Spells
******************************************************************************]]
elseif strClass == "WARLOCK" then

	-- Buffs
	t["Detect Invisibility"] = 1;
	t["Unending Breath"] = 1;

	-- Harmful spells
	t["Banish"] = 3;
	t["Conflagrate"] = 3;
	t["Corruption"] = 3;
	t["Curse of Agony"] = 3;
	t["Curse of Doom"] = 3;
	t["Curse of Exhaustion"] = 3;
	t["Curse of Idiocy"] = 3;
	t["Curse of Recklessness"] = 3;
	t["Curse of Shadow"] = 3;
	t["Curse of Tongues"] = 3;
	t["Curse of Weakness"] = 3;
	t["Curse of the Elements"] = 3;
	t["Death Coil"] = 3;
	t["Drain Life"] = 3;
	t["Drain Mana"] = 3;
	t["Drain Soul"] = 3;
	t["Enslave Demon"] = 3;
	t["Fear"] = 3;
	t["Immolate"] = 3;
	t["Incinerate"] = 3;
	t["Searing Pain"] = 3;
	t["Seed of Corruption"] = 3;
	t["Shadow Bolt"] = 3;
	t["Shadowburn"] = 3;
	t["Siphon Life"] = 3;
	t["Soul Fire"] = 3;
	t["Unstable Affliction"] = 3;

	-- Harmful ground/non-targeted
	--t["Hellfire"] =
	--t["Howl of Terror"] =
	--t["Inferno"] =
    --t["Rain of Fire"] =
    --t["Shadowfury"] =
    
	-- Summons
	--t["Create Firestone"] =
	--t["Create Healthstone"] =
	--t["Create Soulstone"] =
	--t["Create Spellstone"] =
    --t["Ritual of Doom"] =
    --t["Ritual of Souls"] =
    --t["Ritual of Summoning"] =
	--t["Summon Felhunter"] =
	--t["Summon Imp"] =
	--t["Summon Succubus"] =
	--t["Summon Voidwalker"] =
	
	-- Self buffs / pet targeted
	--t["Dark Pact"] =
	--t["Demon Armor"] =
	--t["Demon Skin"] =
    --t["Fel Armor"] =
    --t["Health Funnel"] =
    --t["Life Tap"] =
    --t["Sense Demons"] =
    --t["Shadow Ward"] =
    --t["Soulshatter"] =
    --t["Summon Dreadsteed"] =
    --t["Summon Felsteed"] =
    
--[[****************************************************************************
WARRIOR Spells
******************************************************************************]]
elseif strClass == "WARRIOR" then

	-- Intervene
	t["Intervene"] = 1;

	-- Taunt
	t["Taunt"] = 3;
	
	-- Stances
	--t["Battle Stance"] =
	--t["Berserker Stance"] =
	--t["Defensive Stance"] =
	
	-- Non-targeted skills
	--t["Battle Shout"] =
	--t["Challenging Shout"] =
	--t["Cleave"] =
	--t["Commanding Shout"] =
	--t["Demoralizing Shout"] =
	--t["Heroic Strike"] =
	--t["Thunder Clap"] =
	--t["Whirlwind"] =
	
	-- Self buffs
	--t["Berserker Rage"] =
	--t["Bloodrage"] =
	--t["Rampage"] =
	--t["Recklessness"] =
	--t["Retaliation"] =
	--t["Shield Block"] =
	--t["Shield Wall"] =
	--t["Spell Reflection"] =
	
	-- Targeted skills
	--t["Bloodthirst"] =
	--t["Charge"] =
	--t["Devastate"] =
	--t["Disarm"] =
	--t["Execute"] =
	--t["Hamstring"] =
	--t["Intercept"] =
	--t["Intimidating Shout"] =
	--t["Mocking Blow"] =
	--t["Mortal Strike"] =
	--t["Overpower"] =
	--t["Pummel"] =
	--t["Rend"] =
	--t["Revenge"] =
	--t["Shield Bash"] =
	--t["Shield Slam"] =
	--t["Slam"] =
	--t["Sunder Armor"] =
	--t["Victory Rush"] =
	
	
end;
--[[****************************************************************************
RACIAL Spells
******************************************************************************]]
t["Mana Tap"] = 3;
t["Gift of the Naaru"] = 1;

--[[****************************************************************************
BANDAGES
******************************************************************************]]

t["Linen Bandage"] = 2
t["Heavy Linen Bandage"] = 2
t["Wool Bandage"] = 2
t["Heavy Wool Bandage"] = 2
t["Silk Bandage"] = 2
t["Heavy Silk Bandage"] = 2
t["Mageweave Bandage"] = 2
t["Heavy Mageweave Bandage"] = 2
t["Runecloth Bandage"] = 2
t["Heavy Runecloth Bandage"] = 2
t["Netherweave Bandage"] = 2
t["Heavy Netherweave Bandage"] = 2
t["Warsong Gulch Silk Bandage"] = 2
t["Highlander's Silk Bandage"] = 2
t["Arathi Basin Silk Bandage"] = 2
t["Defiler's Silk Bandage"] = 2
t["Warsong Gulch Mageweave Bandage"] = 2
t["Highlander's Mageweave Bandage"] = 2
t["Arathi Basin Mageweave Bandage"] = 2
t["Defiler's Mageweave Bandage"] = 2
t["Defiler's Runecloth Bandage"] = 2
t["Warsong Gulch Runecloth Bandage"] = 2
t["Alterac Heavy Runecloth Bandage"] = 2
t["Arathi Basin Runecloth Bandage"] = 2
t["Highlander's Runecloth Bandage"] = 2



-- ALL editing must be done ABOVE this line!------------------------------------
return t;

end